@@ -1,7 +1,5 @@
 package Exception::DB;
-$Exception::DB::VERSION = '0.014';
-use qbit;
-
+$Exception::DB::VERSION = '0.015';
 use base qw(Exception);
 
-TRUE;
+1;
