@@ -1,7 +1,5 @@
 package Exception::DB::DuplicateEntry;
-$Exception::DB::DuplicateEntry::VERSION = '0.014';
-use qbit;
-
+$Exception::DB::DuplicateEntry::VERSION = '0.015';
 use base qw(Exception::DB);
 
-TRUE;
+1;
