@@ -1,3 +1,4 @@
+
 =head1 Name
  
 QBit::Application::Model::DB - base class for DB.
@@ -27,7 +28,7 @@ apt-get install libqbit-application-model-db-perl (http://perlhub.ru/)
 =cut
 
 package QBit::Application::Model::DB;
-$QBit::Application::Model::DB::VERSION = '0.014';
+$QBit::Application::Model::DB::VERSION = '0.015';
 use qbit;
 
 use base qw(QBit::Application::Model);
@@ -427,10 +428,10 @@ sub transaction {
     catch {
         my $ex = shift;
 
-        unless ($ex->isa('Exception::DB')) {
-            $self->rollback();
-        } else {
+        if ($ex->isa('Exception::DB')) {
             $self->{'__SAVEPOINTS__'} = 0;
+        } else {
+            $self->rollback();
         }
 
         throw $ex;
